summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ANNOUNCE19
-rw-r--r--CHANGES3
-rw-r--r--CMakeLists.txt2
-rw-r--r--LICENSE4
-rw-r--r--README2
-rw-r--r--configure.ac4
-rw-r--r--libpng-manual.txt8
-rw-r--r--libpng.321
-rw-r--r--libpngpf.34
-rw-r--r--png.52
-rw-r--r--png.c6
-rw-r--r--png.h23
-rw-r--r--pngconf.h2
-rw-r--r--pngtest.c2
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt10
-rw-r--r--scripts/def.c2
-rw-r--r--scripts/libpng-config-head.in2
-rw-r--r--scripts/libpng.pc.in2
-rw-r--r--scripts/makefile.ne12bsd2
-rw-r--r--scripts/makefile.netbsd2
-rw-r--r--scripts/makefile.openbsd2
-rw-r--r--scripts/pnglibconf.h.prebuilt4
-rw-r--r--scripts/symbols.def2
25 files changed, 69 insertions, 65 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index aaf782b05..c75f45b82 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,4 +1,4 @@
-Libpng 1.6.19beta05 - October 15, 2015
+Libpng 1.6.19rc01 - October 23, 2015
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -8,20 +8,20 @@ Files available for download:
Source files with LF line endings (for Unix/Linux) and with a
"configure" script
- 1.6.19beta05.tar.xz (LZMA-compressed, recommended)
- 1.6.19beta05.tar.gz
+ 1.6.19rc01.tar.xz (LZMA-compressed, recommended)
+ 1.6.19rc01.tar.gz
Source files with CRLF line endings (for Windows), without the
"configure" script
- lp1619b05.7z (LZMA-compressed, recommended)
- lp1619b05.zip
+ lp1619r01.7z (LZMA-compressed, recommended)
+ lp1619r01.zip
Other information:
- 1.6.19beta05-README.txt
- 1.6.19beta05-LICENSE.txt
- libpng-1.6.19beta05-*.asc (armored detached GPG signatures)
+ 1.6.19rc01-README.txt
+ 1.6.19rc01-LICENSE.txt
+ libpng-1.6.19rc01-*.asc (armored detached GPG signatures)
Changes since the last public release (1.6.18):
@@ -103,7 +103,8 @@ Version 1.6.19beta04 [October 15, 2015]
code (bug report by Curtis Leach, fix by John Bowler).
Added sPLT support to pngtest.c
-Version 1.6.19beta05 [October 15, 2015]
+Version 1.6.19rc01 [October 23, 2015]
+ No changes.
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
diff --git a/CHANGES b/CHANGES
index 16b8cf7a8..27455bcfa 100644
--- a/CHANGES
+++ b/CHANGES
@@ -5387,7 +5387,8 @@ Version 1.6.19beta04 [October 15, 2015]
code (bug report by Curtis Leach, fix by John Bowler).
Added sPLT support to pngtest.c
-Version 1.6.19beta05 [October 15, 2015]
+Version 1.6.19rc01 [October 23, 2015]
+ No changes.
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
diff --git a/CMakeLists.txt b/CMakeLists.txt
index e7628aaf8..ef782f812 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -261,7 +261,7 @@ endif(NOT WIN32 OR CYGWIN OR MINGW)
# SET UP LINKS
if(PNG_SHARED)
set_target_properties(${PNG_LIB_NAME} PROPERTIES
-# VERSION 16.${PNGLIB_RELEASE}.1.6.19beta05
+# VERSION 16.${PNGLIB_RELEASE}.1.6.19rc01
VERSION 16.${PNGLIB_RELEASE}.0
SOVERSION 16
CLEAN_DIRECT_OUTPUT 1)
diff --git a/LICENSE b/LICENSE
index 6710003f4..8ff1c6860 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.0.7, July 1, 2000, through 1.6.19beta05, October 15, 2015, are
+libpng versions 1.0.7, July 1, 2000, through 1.6.19rc01, October 23, 2015, are
Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.0.6
with the following individuals added to the list of Contributing Authors:
@@ -104,4 +104,4 @@ the additional disclaimers inserted at version 1.0.7.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-October 15, 2015
+October 23, 2015
diff --git a/README b/README
index 7d8c84cb4..1af35b376 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.6.19beta05 - October 15, 2015 (shared library 16.0)
+README for libpng version 1.6.19rc01 - October 23, 2015 (shared library 16.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/configure.ac b/configure.ac
index f18645ba0..88cada207 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,7 +18,7 @@ AC_PREREQ([2.68])
dnl Version number stuff here:
-AC_INIT([libpng],[1.6.19beta05],[png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng],[1.6.19rc01],[png-mng-implement@lists.sourceforge.net])
AC_CONFIG_MACRO_DIR([scripts])
# libpng does not follow GNU file name conventions (hence 'foreign')
@@ -39,7 +39,7 @@ dnl automake, so the following is not necessary (and is not defined anyway):
dnl AM_PREREQ([1.11.2])
dnl stop configure from automagically running automake
-PNGLIB_VERSION=1.6.19beta05
+PNGLIB_VERSION=1.6.19rc01
PNGLIB_MAJOR=1
PNGLIB_MINOR=6
PNGLIB_RELEASE=19
diff --git a/libpng-manual.txt b/libpng-manual.txt
index 1c4d5d2ce..afdf291f0 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.6.19beta05 - October 15, 2015
+ libpng version 1.6.19rc01 - October 23, 2015
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.6.19beta05 - October 15, 2015
+ libpng versions 0.97, January 1998, through 1.6.19rc01 - October 23, 2015
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -5314,13 +5314,13 @@ Other rules can be inferred by inspecting the libpng source.
XVI. Y2K Compliance in libpng
-October 15, 2015
+October 23, 2015
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.6.19beta05 are Y2K compliant. It is my belief that earlier
+upward through 1.6.19rc01 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has two year fields. One is a 2-byte unsigned integer
diff --git a/libpng.3 b/libpng.3
index e4b361d39..7491f064a 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "October 15, 2015"
+.TH LIBPNG 3 "October 23, 2015"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.6.19beta05
+libpng \- Portable Network Graphics (PNG) Reference Library 1.6.19rc01
.SH SYNOPSIS
\fB
#include <png.h>\fP
@@ -508,7 +508,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.6.19beta05 - October 15, 2015
+ libpng version 1.6.19rc01 - October 23, 2015
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -519,7 +519,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.6.19beta05 - October 15, 2015
+ libpng versions 0.97, January 1998, through 1.6.19rc01 - October 23, 2015
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -5822,13 +5822,13 @@ Other rules can be inferred by inspecting the libpng source.
.SH XVI. Y2K Compliance in libpng
-October 15, 2015
+October 23, 2015
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.6.19beta05 are Y2K compliant. It is my belief that earlier
+upward through 1.6.19rc01 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -6086,7 +6086,8 @@ the first widely used release:
1.6.18beta01-09 16 10618 16.so.16.18[.0]
1.6.18rc01-03 16 10618 16.so.16.18[.0]
1.6.18 16 10618 16.so.16.18[.0]
- 1.6.19beta01-05 16 10619 16.so.16.19[.0]
+ 1.6.19beta01-04 16 10619 16.so.16.19[.0]
+ 1.6.19rc01 16 10619 16.so.16.19[.0]
Henceforth the source version will match the shared-library minor
and patch numbers; the shared-library major version number will be
@@ -6143,7 +6144,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.6.19beta05 - October 15, 2015:
+Libpng version 1.6.19rc01 - October 23, 2015:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -6166,7 +6167,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.0.7, July 1, 2000, through 1.6.19beta05, October 15, 2015, are
+libpng versions 1.0.7, July 1, 2000, through 1.6.19rc01, October 23, 2015, are
Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.0.6
with the following individuals added to the list of Contributing Authors:
@@ -6260,7 +6261,7 @@ the additional disclaimers inserted at version 1.0.7.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-October 15, 2015
+October 23, 2015
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index 9645b6585..e141d15a5 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "October 15, 2015"
+.TH LIBPNGPF 3 "October 23, 2015"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.6.19beta05
+libpng \- Portable Network Graphics (PNG) Reference Library 1.6.19rc01
(private functions)
.SH SYNOPSIS
\fB#include \fI"pngpriv.h"
diff --git a/png.5 b/png.5
index 7ffc1d337..5fd57a043 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "October 15, 2015"
+.TH PNG 5 "October 23, 2015"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index 27aa04ee7..eb9ad3a03 100644
--- a/png.c
+++ b/png.c
@@ -14,7 +14,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_6_19beta05 Your_png_h_is_not_version_1_6_19beta05;
+typedef png_libpng_version_1_6_19rc01 Your_png_h_is_not_version_1_6_19rc01;
/* Tells libpng that we have already handled the first "num_bytes" bytes
* of the PNG file signature. If the PNG data is embedded into another
@@ -775,13 +775,13 @@ png_get_copyright(png_const_structrp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.6.19beta05 - October 15, 2015" PNG_STRING_NEWLINE \
+ "libpng version 1.6.19rc01 - October 23, 2015" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2015 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.6.19beta05 - October 15, 2015\
+ return "libpng version 1.6.19rc01 - October 23, 2015\
Copyright (c) 1998-2015 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index a98c7e073..a40925c00 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.6.19beta05, July 23, 2015
+ * libpng version 1.6.19rc01, July 23, 2015
*
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index c325da50f..1531b5e4c 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -2057,4 +2057,4 @@ main(void)
#endif
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_6_19beta05 Your_png_h_is_not_version_1_6_19beta05;
+typedef png_libpng_version_1_6_19rc01 Your_png_h_is_not_version_1_6_19rc01;
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 63118fe1d..d6e096ccc 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.6.19beta05 - October 15, 2015
+libpng version 1.6.19rc01 - October 23, 2015
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 7811d94e4..872d69b50 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.6.19beta05 - October 15, 2015
+ * libpng version 1.6.19rc01 - October 23, 2015
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 4dfa258cc..3063956d0 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,9 +1,9 @@
-Makefiles for libpng version 1.6.19beta05 - October 15, 2015
+Makefiles for libpng version 1.6.19rc01 - October 23, 2015
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng16.so.16.1.6.19beta05)
+ (gcc, creates libpng16.so.16.1.6.19rc01)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -33,12 +33,12 @@ pnglibconf.h.prebuilt => Stores configuration settings
makefile.os2 => OS/2 Makefile (gcc and emx, requires libpng.def)
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
makefile.sggcc => Silicon Graphics (gcc,
- creates libpng16.so.16.1.6.19beta05)
+ creates libpng16.so.16.1.6.19rc01)
makefile.sgi => Silicon Graphics IRIX makefile (cc, creates static lib)
makefile.solaris => Solaris 2.X makefile (gcc,
- creates libpng16.so.16.1.6.19beta05)
+ creates libpng16.so.16.1.6.19rc01)
makefile.so9 => Solaris 9 makefile (gcc,
- creates libpng16.so.16.1.6.19beta05)
+ creates libpng16.so.16.1.6.19rc01)
makefile.std => Generic UNIX makefile (cc, creates static libpng.a)
makefile.sunos => Sun makefile
makefile.32sunu => Sun Ultra 32-bit makefile
diff --git a/scripts/def.c b/scripts/def.c
index ae7fb2348..f54dae422 100644
--- a/scripts/def.c
+++ b/scripts/def.c
@@ -21,7 +21,7 @@ PNG_DFN "OS2 DESCRIPTION "PNG image compression library""
PNG_DFN "OS2 CODE PRELOAD MOVEABLE DISCARDABLE"
PNG_DFN ""
PNG_DFN "EXPORTS"
-PNG_DFN ";Version 1.6.19beta05"
+PNG_DFN ";Version 1.6.19rc01"
#define PNG_EXPORTA(ordinal, type, name, args, attributes)\
PNG_DFN "@" SYMBOL_PREFIX "@@" name "@"
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index fe949f56f..5eb239a57 100644
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
# Modeled after libxml-config.
-version=1.6.19beta05
+version=1.6.19rc01
prefix=""
libdir=""
libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index 3df3f481c..130524a0c 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@ includedir=@includedir@/libpng16
Name: libpng
Description: Loads and saves PNG files
-Version: 1.6.19beta05
+Version: 1.6.19rc01
Libs: -L${libdir} -lpng16
Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index e362a8673..2c0364287 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include/libpng16
LIB= png16
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.6.19beta05
+SHLIB_MINOR= 1.6.19rc01
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index 706f3042c..fd7c0fc25 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include
LIB= png
SHLIB_MAJOR= 16
-SHLIB_MINOR= 1.6.19beta05
+SHLIB_MINOR= 1.6.19rc01
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index a51440be1..5f413d43c 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@ LIBDIR= ${PREFIX}/lib
MANDIR= ${PREFIX}/man/cat
SHLIB_MAJOR= 16
-SHLIB_MINOR= 1.6.19beta05
+SHLIB_MINOR= 1.6.19rc01
LIB= png
SRCS= png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 808a5861f..1a91f3538 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -1,8 +1,8 @@
-/* libpng 1.6.19beta05 STANDARD API DEFINITION */
+/* libpng 1.6.19rc01 STANDARD API DEFINITION */
/* pnglibconf.h - library build configuration */
-/* Libpng version 1.6.19beta05 - October 15, 2015 */
+/* Libpng version 1.6.19rc01 - October 23, 2015 */
/* Copyright (c) 1998-2014 Glenn Randers-Pehrson */
diff --git a/scripts/symbols.def b/scripts/symbols.def
index 9597e23e9..8c8e8ebd5 100644
--- a/scripts/symbols.def
+++ b/scripts/symbols.def
@@ -1,4 +1,4 @@
-;Version 1.6.19beta05
+;Version 1.6.19rc01
;--------------------------------------------------------------
; LIBPNG symbol list as a Win32 DEF file
; Contains all the symbols that can be exported from libpng
diff --git a/png.h b/png.h
index 301444b69..72f66c456 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.6.19beta05, October 15, 2015
*
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -12,7 +12,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.6.19beta05, October 15, 2015: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -219,7 +219,8 @@
* 1.6.18beta01-09 16 10618 16.so.16.18[.0]
* 1.6.18rc01-03 16 10618 16.so.16.18[.0]
* 1.6.18 16 10618 16.so.16.18[.0]
- * 1.6.19beta01-05 16 10619 16.so.16.19[.0]
+ * 1.6.19beta01-04 16 10619 16.so.16.19[.0]
+ * 1.6.19rc01 16 10619 16.so.16.19[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -251,7 +252,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.0.7, July 1, 2000, through 1.6.19beta05, October 15, 2015, are
* Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.0.6
* with the following individuals added to the list of Contributing Authors:
@@ -360,13 +361,13 @@
* Y2K compliance in libpng:
* =========================
*
- * October 15, 2015
+ * October 23, 2015
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.6.19beta05 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -428,9 +429,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.6.19beta05"
+#define PNG_LIBPNG_VER_STRING "1.6.19rc01"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.6.19beta05 - October 15, 2015\n"
+ " libpng version 1.6.19rc01 - October 23, 2015\n"
#define PNG_LIBPNG_VER_SONUM 16
#define PNG_LIBPNG_VER_DLLNUM 16
@@ -444,7 +445,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 05
+#define PNG_LIBPNG_VER_BUILD 01
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -461,7 +462,7 @@
#define PNG_LIBPNG_BUILD_SPECIAL 32 /* Cannot be OR'ed with
PNG_LIBPNG_BUILD_PRIVATE */
-#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_BETA
+#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_RC
/* Careful here. At one time, Guy wanted to use 082, but that would be octal.
* We must not include leading zeros.
@@ -579,7 +580,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_6_19beta05;
+typedef char* png_libpng_version_1_6_19rc01;
/* Basic control structions. Read libpng-manual.txt or libpng.3 for more info.
*
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.6.19beta05, October 15, 2015
+ * libpng version 1.6.19rc01, October 23, 2015
*
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -12,7 +12,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.6.19beta05, October 15, 2015: Glenn
+ * libpng versions 0.97, January 1998, through 1.6.19rc01, October 23, 2015: Glenn
* See also "Contributing Authors", below.
*
@@ -251,7 +252,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.0.7, July 1, 2000, through 1.6.19beta05, October 15, 2015, are
+ * libpng versions 1.0.7, July 1, 2000, through 1.6.19rc01, October 23, 2015, are
* Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.0.6
@@ -360,13 +361,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.6.19beta05 are Y2K compliant. It is my belief that
+ * upward through 1.6.19rc01 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*